from jaxkuramoto import solver, theory, distribution
from jaxkuramoto.kuramoto import Kuramoto
from jaxkuramoto.ode import odeint